@@ -1614,205 +1614,200 @@ class nxpprog:
         return ' '.join([id1, id2, id3, id4])
 
 
-class NxpprogWrapper:
-    def signal_handler(self, sig, frame):
-        if prog:
-            prog.device.close()
-        logging.error('Ctrl+C Pressed bailing out!')
-        sys.exit(0)
-
-    def main(self, argv=None):
-        global prog
-
-        args = parser.parse_args()
-
-        # defaults
-        osc_freq = 16000  # kHz
-        baud = 115200
-        device = None
-        cpu = "autodetect"
-        filename = ""
-        flash_addr_base = 0
-        erase_all = False
-        erase_only = False
-        verbose = False
-        verify = False
-        verify_only = False
-        blank_check = False
-        xonxoff = False
-        start = False
-        control = False
-        filetype = "autodetect"
-        select_bank = False
-        read = False
-        readlen = 0
-        get_serial_number = False
-        udp = False
-        port = -1
-        mac = ""  # "0C-1D-12-E0-1F-10"
-
-        if args.list:
-            logging.info("Supported cpus:")
-            for val in sorted(cpu_parms.keys()):
-                logging.info(" %s" % val)
-            sys.exit(0)
-        if args.verbose:
-            logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
-        else:
-            logging.basicConfig(stream=sys.stdout, level=logging.INFO)
-        if args.binary:
-            filename = args.binary
-        if args.device:
-            device = args.device
-        if args.cpu:
-            cpu = args.cpu
-        if args.xonxoff:
-            xonxoff = True
-        if args.osfreq:
-            os_freq = args.osfreq
-        if args.addr:
-            addr = int(args.addr, 0)
-        if args.baud:
-            baud = args.baud
-        if args.eraseall:
-            erase_all = args.eraseall
-        if args.eraseonly:
-            erase_only = args.eraseonly
-        if args.verify:
-            verify = True
-        if args.verifyonly:
-            verify = True
-            verify_only = True
-        if args.blankcheck:
-            verify = True
-            blank_check = True
-        if args.control:
-            control = True
-        if args.filetype:
-            filetype = args.filetype
-        if not (filetype == "bin" or filetype == "ihex"):
-            panic("Invalid filetype: %s" % filetype)
-        if args.start:
-            start = True
-            if args.addr:
-                startaddr = int(args.addr, 0)
-            else:
-                startaddr = 0
-        if args.bank:
-            select_bank = True
-            bank = args.bank
-        if args.read:
-            read = True
-            readfile = a
-        if args.serialnumber:
-            get_serial_number = True
-        if args.len:
-            readlen = args.len
-        if args.udp:
-            udp = True
-        if args.port:
-            port = int(args.port)
-        if args.mac:
-            mac = args.mac
-
-        if cpu != "autodetect" and not cpu in cpu_parms:
-            panic("Unsupported cpu %s" % cpu)
-
-        port_finder = AutoLPCPortFinder()
-        if not device:
-            device = port_finder.find_lpc_port()
-            if device == None:
-                panic(
-                    "Scanned serial ports, but could not find an LPC device. Are you sure it is connected to your computer?\n\n")
-
-        if udp:
-            if '.' in device:
-                if ':' in device:
-                    device, port = tuple(device.split(':'))
-                    port = int(port)
-                    if port < 0 or port > 65535:
-                        panic("Bad port number: %d" % port)
-                parts = [int(x) for x in device.split('.')]
-                if len(parts) != 4 or min(parts) < 0 or max(parts) > 255:
-                    panic("Bad IPv4-address: %s" % device)
-                device = '.'.join([str(x) for x in parts])
-            elif ':' in device:
-                # panic("Bad IPv6-address: %s" % device)
-                pass
-            else:
-                panic("Bad IP-address: %s" % device)
-            if port < 0:
-                port = 41825
-            if mac:
-                parts = [int(x, 16) for x in mac.split('-')]
-                if len(parts) != 6 or min(parts) < 0 or max(parts) > 255:
-                    panic("Bad MAC-address: %s" % mac)
-                mac = '-'.join(['%02x' % x for x in parts])
-                logging.info("cpu=%s ip=%s:%d mac=%s" %
-                             (cpu, device, port, mac))
-            else:
-                logging.info("cpu=%s ip=%s:%d" % (cpu, device, port))
-        else:
-            logging.info("cpu=%s oscfreq=%d device=%s baud=%d" %
-                         (cpu, osc_freq, device, baud))
-
-        prog = nxpprog(cpu, device, baud, osc_freq, xonxoff,
-                       control, (device, port, mac) if udp else None, verify)
-
-        if erase_only:
-            prog.erase_all(verify)
-        elif blank_check:
-            prog.blank_check_all()
-        elif start:
-            prog.start(startaddr)
-        elif select_bank:
-            prog.select_bank(bank)
-        elif get_serial_number:
-            sn = prog.get_serial_number()
-            sys.stdout.write(sn)
-        elif read:
-            if not readlen:
-                panic("Read length is 0")
-            fd = open(readfile, "w")
-            prog.read_block(flash_addr_base, readlen, fd)
-            fd.close()
-        else:
-
-            if filetype == "autodetect":
-                filetype = "ihex" if filename.endswith('hex') else "bin"
-
-            if filetype == "ihex":
-                ih = ihex.ihex(filename)
-                (flash_addr_base, image) = ih.flatten()
-            else:
-                image = open(filename, "rb").read()
-
-            if not verify_only:
-                start = time.time()
-                success = prog.prog_image(
-                    image, flash_addr_base, erase_all, verify)
-                stop = time.time()
-                elapsed = stop - start
-                logging.info("Programmed %s in %.1f seconds" %
-                             ("successfully" if success else "with errors", elapsed))
-
-            if verify:
-                start = time.time()
-                success = prog.verify_image(flash_addr_base, image)
-                stop = time.time()
-                elapsed = stop - start
-                logging.info("Verified %s in %.1f seconds" %
-                             ("successfully" if success else "with errors", elapsed))
-
-            if not verify_only:
-                prog.start(flash_addr_base)
-
+def signal_handler(sig, frame):
+    if prog:
         prog.device.close()
+    logging.error('Ctrl+C Pressed bailing out!')
+    sys.exit(0)
 
-    def run_nxpprog(self):
-        signal.signal(signal.SIGINT, self.signal_handler)
-        sys.exit(self.main())
+def main(argv=None):
+    global prog
+
+    args = parser.parse_args()
+
+    # defaults
+    osc_freq = 16000  # kHz
+    baud = 115200
+    device = None
+    cpu = "autodetect"
+    filename = ""
+    flash_addr_base = 0
+    erase_all = False
+    erase_only = False
+    verbose = False
+    verify = False
+    verify_only = False
+    blank_check = False
+    xonxoff = False
+    start = False
+    control = False
+    filetype = "autodetect"
+    select_bank = False
+    read = False
+    readlen = 0
+    get_serial_number = False
+    udp = False
+    port = -1
+    mac = ""  # "0C-1D-12-E0-1F-10"
+
+    if args.list:
+        logging.info("Supported cpus:")
+        for val in sorted(cpu_parms.keys()):
+            logging.info(" %s" % val)
+        sys.exit(0)
+    if args.verbose:
+        logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
+    else:
+        logging.basicConfig(stream=sys.stdout, level=logging.INFO)
+    if args.binary:
+        filename = args.binary
+    if args.device:
+        device = args.device
+    if args.cpu:
+        cpu = args.cpu
+    if args.xonxoff:
+        xonxoff = True
+    if args.osfreq:
+        os_freq = args.osfreq
+    if args.addr:
+        addr = int(args.addr, 0)
+    if args.baud:
+        baud = args.baud
+    if args.eraseall:
+        erase_all = args.eraseall
+    if args.eraseonly:
+        erase_only = args.eraseonly
+    if args.verify:
+        verify = True
+    if args.verifyonly:
+        verify = True
+        verify_only = True
+    if args.blankcheck:
+        verify = True
+        blank_check = True
+    if args.control:
+        control = True
+    if args.filetype:
+        filetype = args.filetype
+    if not (filetype == "bin" or filetype == "ihex"):
+        panic("Invalid filetype: %s" % filetype)
+    if args.start:
+        start = True
+        if args.addr:
+            startaddr = int(args.addr, 0)
+        else:
+            startaddr = 0
+    if args.bank:
+        select_bank = True
+        bank = args.bank
+    if args.read:
+        read = True
+        readfile = a
+    if args.serialnumber:
+        get_serial_number = True
+    if args.len:
+        readlen = args.len
+    if args.udp:
+        udp = True
+    if args.port:
+        port = int(args.port)
+    if args.mac:
+        mac = args.mac
+
+    if cpu != "autodetect" and not cpu in cpu_parms:
+        panic("Unsupported cpu %s" % cpu)
+
+    port_finder = AutoLPCPortFinder()
+    if not device:
+        device = port_finder.find_lpc_port()
+        if device == None:
+            panic(
+                "Scanned serial ports, but could not find an LPC device. Are you sure it is connected to your computer?\n\n")
+
+    if udp:
+        if '.' in device:
+            if ':' in device:
+                device, port = tuple(device.split(':'))
+                port = int(port)
+                if port < 0 or port > 65535:
+                    panic("Bad port number: %d" % port)
+            parts = [int(x) for x in device.split('.')]
+            if len(parts) != 4 or min(parts) < 0 or max(parts) > 255:
+                panic("Bad IPv4-address: %s" % device)
+            device = '.'.join([str(x) for x in parts])
+        elif ':' in device:
+            # panic("Bad IPv6-address: %s" % device)
+            pass
+        else:
+            panic("Bad IP-address: %s" % device)
+        if port < 0:
+            port = 41825
+        if mac:
+            parts = [int(x, 16) for x in mac.split('-')]
+            if len(parts) != 6 or min(parts) < 0 or max(parts) > 255:
+                panic("Bad MAC-address: %s" % mac)
+            mac = '-'.join(['%02x' % x for x in parts])
+            logging.info("cpu=%s ip=%s:%d mac=%s" %
+                            (cpu, device, port, mac))
+        else:
+            logging.info("cpu=%s ip=%s:%d" % (cpu, device, port))
+    else:
+        logging.info("cpu=%s oscfreq=%d device=%s baud=%d" %
+                        (cpu, osc_freq, device, baud))
+
+    prog = nxpprog(cpu, device, baud, osc_freq, xonxoff,
+                    control, (device, port, mac) if udp else None, verify)
+
+    if erase_only:
+        prog.erase_all(verify)
+    elif blank_check:
+        prog.blank_check_all()
+    elif start:
+        prog.start(startaddr)
+    elif select_bank:
+        prog.select_bank(bank)
+    elif get_serial_number:
+        sn = prog.get_serial_number()
+        sys.stdout.write(sn)
+    elif read:
+        if not readlen:
+            panic("Read length is 0")
+        fd = open(readfile, "w")
+        prog.read_block(flash_addr_base, readlen, fd)
+        fd.close()
+    else:
+
+        if filetype == "autodetect":
+            filetype = "ihex" if filename.endswith('hex') else "bin"
+
+        if filetype == "ihex":
+            ih = ihex.ihex(filename)
+            (flash_addr_base, image) = ih.flatten()
+        else:
+            image = open(filename, "rb").read()
+
+        if not verify_only:
+            start = time.time()
+            success = prog.prog_image(
+                image, flash_addr_base, erase_all, verify)
+            stop = time.time()
+            elapsed = stop - start
+            logging.info("Programmed %s in %.1f seconds" %
+                            ("successfully" if success else "with errors", elapsed))
+
+        if verify:
+            start = time.time()
+            success = prog.verify_image(flash_addr_base, image)
+            stop = time.time()
+            elapsed = stop - start
+            logging.info("Verified %s in %.1f seconds" %
+                            ("successfully" if success else "with errors", elapsed))
+
+        if not verify_only:
+            prog.start(flash_addr_base)
+
+    prog.device.close()
 
 if __name__ == '__main__':
-    wrapper = nxpprog.NxpprogWrapper()
-    wrapper.run_nxpprog()
+    signal.signal(signal.SIGINT, signal_handler)
+    sys.exit(main())
